@@ -17,7 +17,7 @@ extern "C"
 {
 #endif
 
-#include "m_pd.h"
+#include "../pure-data/src/m_pd.h"
 
 /* initializing pd */
 
